@@ -47,7 +47,7 @@
 #include <zlib.h>
 
 /* Need socket header? */
-#ifdef HAVE_LIBSOCKET
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
 
@@ -116,6 +116,7 @@ int      raiseSigChild = 1;
 
 time_t runtime;
 time_t start_time, end_time;
+float  temp_time;
 
 extern char *our_gzgets(gzFile, char *, int);  /* external our_gzgets func */
 
@@ -338,11 +339,16 @@ int dns_resolver(void *log_fp)
    {
       if (verbose<2 && time_me) printf("DNS: ");
       printf("%lu %s ",listEntries, msg_addresses);
-      printf("%s %.2f %s", msg_in, (float)(end_time-start_time)/CLK_TCK,
-                           msg_seconds);
+
+      /* get processing time (end-start) */
+      temp_time = (float)(end_time-start_time)/CLK_TCK;
+      printf("%s %.2f %s", msg_in, temp_time, msg_seconds);
 
       /* calculate records per second */
-      i=((int)((float)listEntries / ((float)(end_time-start_time)/CLK_TCK)) );
+      if (temp_time)
+         i=( (int)((float)listEntries/temp_time) );
+      else i=0;
+
       if ( (i>0) && (i<=listEntries) ) printf(", %d/sec\n", i);
          else  printf("\n");
    }
@@ -429,14 +435,23 @@ static void process_list(DNODEPTR l_list)
 
                   if((res_ent = gethostbyaddr(child_buf, size, AF_INET)))
                   {
-                     if(debug_mode)
-                        printf("Child got %s for %lx(%d)\n",
-                               res_ent->h_name,
-                               *((unsigned long *)child_buf),
-                               size);
-			  
-                     strcpy(child_buf, res_ent->h_name);
-                     size = strlen(child_buf);
+                     /* must be at least 4 chars */
+                     if (strlen(res_ent->h_name)>3)
+                     {
+                        if(debug_mode)
+                           printf("Child got %s for %lx(%d), %d bytes\n",
+                                   res_ent->h_name,
+                                   *((unsigned long *)child_buf),
+                                   size,strlen(res_ent->h_name));
+
+                        strcpy(child_buf, res_ent->h_name);
+                        size = strlen(child_buf);
+                     }
+                     else
+                     {
+                        if (debug_mode)
+                           printf("gethostbyaddr returned bad h_name!\n");
+                     }
                   }
                   else
                   {
@@ -444,11 +459,11 @@ static void process_list(DNODEPTR l_list)
                         printf("gethostbyaddr returned NULL! (%d)\n",h_errno);
                   }
 
-                  if(debug_mode)
-                     printf("Got %d Bytes as result from gethostbyaddr()\n",
-                     size);
-
-                  write(child[i].inpipe[1], child_buf, size);
+                  if (write(child[i].inpipe[1], child_buf, size) == -1)
+                  {
+                     perror("write error");
+                     exit(1);
+                  }
                }
             }
             close(child[i].inpipe[1]);
@@ -520,24 +535,34 @@ static void process_list(DNODEPTR l_list)
 
                if(trav)  /* something to resolve */
                {
-                  child[i].cur    = trav;
-                  write(child[i].outpipe[1], &(trav->addr.s_addr),
-                        sizeof(trav->addr.s_addr)); 
+                  if (write(child[i].outpipe[1], &(trav->addr.s_addr),
+                     sizeof(trav->addr.s_addr)) != -1)
+                  {
+                     /* We will watch this child */
+                     child[i].cur    = trav;
+                     FD_SET(child[i].inpipe[0], &rd_set);
+                     max_fd = MAX(max_fd, child[i].inpipe[0]);
 
-                  /* We will watch this child */
-                  FD_SET(child[i].inpipe[0], &rd_set);
-                  max_fd = MAX(max_fd, child[i].inpipe[0]);
+                     if(debug_mode)
+                        printf("Giving %s (%lx) to Child %d for resolving\n",
+                                child[i].cur->string,
+                                (unsigned long)child[i].cur->addr.s_addr, i);
 
-                  if(debug_mode)
-                     printf("Giving %s (%lx) to Child %d for resolving\n",
-                             child[i].cur->string,
-                             (unsigned long)child[i].cur->addr.s_addr, i);
-
-                  trav = trav->llist;
+                     trav = trav->llist;
+                  }
+                  else  /* write error */
+                  {
+                     if(errno != EINTR)           /* Could be a signal */
+                     {
+                        perror("Could not write to pipe");
+                        close(child[i].outpipe[1]);           /* kill     */
+                        child[i].flags &= ~DNS_CHILD_RUNNING; /* child    */
+                     }
+		  }
                }
                else /* List is complete */
                {
-                  close(child[i].outpipe[1]);                    /* Go away */
+                  close(child[i].outpipe[1]);            /* Go away       */
                   child[i].flags &= ~DNS_CHILD_RUNNING;  /* Child is dead */
                }
             }
@@ -625,7 +650,9 @@ static void process_list(DNODEPTR l_list)
                            if(debug_mode)
                               printf("Could not resolve (%d):  %s\n",
                                      i, child[i].cur->string); 
+                           /*
                            db_put(child[i].cur->string,child[i].cur->string,1);
+                           */
                         }
 
                         if(debug_mode)
