@@ -125,11 +125,13 @@ HNODEPTR new_hnode(char *str)
    if (strlen(str) >= MAXHOST)
    {
       if (verbose)
-      fprintf(stderr,"[new_hnode] %s\n",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
-      str[MAXHOST-1]=0;         /* force to max size */
+      {
+         fprintf(stderr,"[new_hnode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
+      str[MAXHOST-1]=0;
    }
 
    if ( (sptr=malloc(strlen(str)+1))==NULL ) return (HNODEPTR)NULL;
@@ -214,7 +216,7 @@ int put_hnode( char     *str,   /* Hostname  */
                {
                   if ((tstamp-cptr->tstamp)>=visit_timeout)
                   {
-                     if (cptr->tstamp!=0) cptr->visit++;
+                     cptr->visit++;
                      if (htab==sm_htab)
                      {
                         update_exit(cptr->lasturl);
@@ -310,14 +312,16 @@ UNODEPTR new_unode(char *str)
    UNODEPTR newptr;
    char     *sptr;
 
-   if ( strlen(str) >= MAXURLH )
+   if (strlen(str) >= MAXURLH)
    {
       if (verbose)
-      fprintf(stderr,"[new_unode] %s\n",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
-      str[MAXURLH-1]=0;      /* force to max size */
+      {
+         fprintf(stderr,"[new_unode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
+      str[MAXURLH-1]=0;
    }
 
    if ( (sptr=malloc(strlen(str)+1))==NULL) return (UNODEPTR)NULL;
@@ -438,11 +442,13 @@ RNODEPTR new_rnode(char *str)
    if (strlen(str) >= MAXREFH)
    {
       if (verbose)
-      fprintf(stderr,"[new_rnode] %s\n",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
-      str[MAXREFH-1]=0;      /* force to max size */
+      {
+         fprintf(stderr,"[new_rnode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
+      str[MAXREFH-1]=0;
    }
 
    if ( (sptr=malloc(strlen(str)+1))==NULL ) return (RNODEPTR)NULL;
@@ -555,10 +561,12 @@ ANODEPTR new_anode(char *str)
    if (strlen(str) >= MAXAGENT)
    {
       if (verbose)
-      fprintf(stderr,"[new_anode] %s\n",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
+      {
+         fprintf(stderr,"[new_anode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
       str[MAXAGENT-1]=0;
    }
 
@@ -669,10 +677,12 @@ SNODEPTR new_snode(char *str)
    if (strlen(str) >= MAXSRCHH)
    {
       if (verbose)
-      fprintf(stderr,"[new_snode] %s\n",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
+      {
+         fprintf(stderr,"[new_snode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
       str[MAXSRCHH-1]=0;
    }
 
@@ -767,28 +777,30 @@ void	del_slist(SNODEPTR *htab)
 INODEPTR new_inode(char *str)
 {
    INODEPTR newptr;
-   char     *iptr;
+   char     *sptr;
 
    if (strlen(str) >= MAXIDENT)
    {
       if (verbose)
-      fprintf(stderr,"[new_inode] %s",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
-      str[MAXIDENT-1]=0;        /* force to max size */
+      {
+         fprintf(stderr,"[new_inode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
+      str[MAXIDENT-1]=0;
    }
 
-   if ( (iptr=malloc(strlen(str)+1))==NULL ) return (INODEPTR)NULL;
-   strcpy(iptr,str);
+   if ( (sptr=malloc(strlen(str)+1))==NULL ) return (INODEPTR)NULL;
+   strcpy(sptr,str);
 
    if (( newptr = malloc(sizeof(struct inode))) != NULL)
    {
-      newptr->string    =iptr;
+      newptr->string    =sptr;
       newptr->visit     =1;
       newptr->tstamp    =0;
    }
-   else free(iptr);
+   else free(sptr);
    return newptr;
 }
 
@@ -853,9 +865,7 @@ int put_inode( char     *str,   /* ident str */
                if (ispage(log_rec.url))
                {
                   if ((tstamp-cptr->tstamp)>=visit_timeout)
-                  {
-                     if (cptr->tstamp!=0) cptr->visit++;
-                  }
+                     cptr->visit++;
                   cptr->tstamp=tstamp;
                }
                return 0;
@@ -942,10 +952,12 @@ DNODEPTR new_dnode(char *str)
    if (strlen(str) >= MAXHOST)
    {
       if (verbose)
-      fprintf(stderr,"[new_dnode] %s\n",msg_big_one);
-      if (debug_mode)
-           fprintf(stderr,":\n--> %s\n",str);
-      else fprintf(stderr,"\n");
+      {
+         fprintf(stderr,"[new_dnode] %s (%d)",msg_big_one,strlen(str));
+         if (debug_mode)
+            fprintf(stderr,":\n--> %s",str);
+         fprintf(stderr,"\n");
+      }
       str[MAXHOST-1]=0;
    }
 
