@@ -101,8 +101,8 @@ char    *our_gzgets(gzFile, char *, int);           /* our gzgets          */
 /*********************************************/
 
 char    *version     = "2.01";                /* program version          */
-char    *editlvl     = "05";                  /* edit level               */
-char    *moddate     = "06-Oct-2000";         /* modification date        */
+char    *editlvl     = "06";                  /* edit level               */
+char    *moddate     = "17-Oct-2000";         /* modification date        */
 char    *copyright   = "Copyright 1997-2000 by Bradford L. Barrett";
 
 int     verbose      = 2;                     /* 2=verbose,1=err, 0=none  */ 
@@ -644,9 +644,10 @@ int main(int argc, char *argv[])
          }
 
          /* check for out of sequence records */
-         if ( rec_tstamp+3600 < cur_tstamp)     /* give up to 1 hr of slop  */
+         if (rec_tstamp/3600 < cur_tstamp/3600)
          {
-            if (!fold_seq_err) { total_ignore++; continue; }
+            if (!fold_seq_err && ((rec_tstamp+SLOP_VAL)/3600<cur_tstamp/3600) )
+               { total_ignore++; continue; }
             else
             {
                rec_sec   = cur_sec;             /* if folding sequence      */
